@@ -51,7 +51,7 @@ impl From<Class> for SecInfo {
 }
 
 /// Error codes for `SecInfo::accept()`
-#[derive(Copy, Clone, PartialEq, Eq)]
+#[derive(Copy, Clone, Debug, PartialEq, Eq)]
 #[non_exhaustive]
 pub enum AcceptError {
     /// CPU cores have not exited from the previous grace period.
@@ -144,7 +144,7 @@ impl SecInfo {
     /// Extend page permissions.
     #[inline]
     #[cfg(target_arch = "x86_64")]
-    pub fn extend_permissions(&self, dest: Page) {
+    pub fn extend(&self, dest: Page) {
         unsafe {
             core::arch::asm!(
                 "xchg       {RBX}, rbx",
